DEFILLAMA_SUPPORTED_PROJECTS = [
    "Lido",
    "Rocket-pool",
    "Binance-staked-eth",
    "Mantle-staked-eth",
    "Frax-ether",
    "Uniswap-v3",
    "Curve-dex",
    "Uniswap-v2",
    "Pancakeswap-amm",
    "Balancer-v2",
    "Pancakeswap-amm-v3",
    "Sushiswap",
    "Thorchain",
    "Convex-finance",
    "Stakestone",
    "Aura",
    "Pendle",
    "Coinwind",
    "Penpie",
    "Aave-v3",
    "Aave-v2",
    "Spark",
    "Compound-v3",
    "Compound-v2",
    "Morpho-aave",
    "Morpho-aavev3",
    "Benqi-lending",
    "Radiant-v2",
    "Yearn-finance",
    "Beefy",
    "Origin-ether",
    "Flamincome",
    "Sommelier",
]
